"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var util_1 = require("../../util");
var di_1 = require("../../di");
var UniversalComponent = /** @class */ (function (_super) {
    __extends(UniversalComponent, _super);
    /**
     * @stable [23.04.2018]
     * @param {TProps} props
     */
    function UniversalComponent(props) {
        var _this = _super.call(this, props) || this;
        _this.plugins = [];
        _this.selfRef = React.createRef();
        _this.onNativeScroll = _this.onNativeScroll.bind(_this);
        var dynamicPluginFactory = _this.uiPlugins.get(_this.constructor);
        if (dynamicPluginFactory) {
            _this.plugins.push(dynamicPluginFactory(_this));
        }
        [].concat(props.plugins || []).forEach(function (plugin) { return _this.registerPlugin(plugin); });
        if (util_1.isFn(props.onScroll)) {
            _this.scrollTask = new util_1.DelayedTask(_this.doScroll.bind(_this), 200);
        }
        return _this;
    }
    /**
     * @stable [23.04.2018]
     */
    UniversalComponent.prototype.componentDidMount = function () {
        this.plugins.forEach(function (plugin) { return plugin.componentDidMount && plugin.componentDidMount(); });
        var props = this.props;
        if (props.register) {
            props.register(this);
        }
    };
    /**
     * @stable [18.12.2018]
     * @param {Readonly<TProps extends IUniversalComponentProps>} prevProps
     * @param {Readonly<TState>} prevState
     */
    UniversalComponent.prototype.getSnapshotBeforeUpdate = function (prevProps, prevState) {
        this.plugins.forEach(function (plugin) {
            return util_1.isFn(plugin.getSnapshotBeforeUpdate) && plugin.getSnapshotBeforeUpdate(prevProps, prevState);
        });
        return null;
    };
    /**
     * @stable [23.04.2018]
     */
    UniversalComponent.prototype.componentWillUnmount = function () {
        this.plugins.forEach(function (plugin) { return plugin.componentWillUnmount && plugin.componentWillUnmount(); });
        var props = this.props;
        if (props.unregister) {
            props.unregister(this);
        }
        if (util_1.isDef(this.scrollTask)) {
            this.scrollTask.stop();
        }
    };
    /**
     * @stable [23.04.2018]
     * @param {Readonly<TProps extends IUniversalComponentEntity>} prevProps
     * @param {Readonly<TState>} prevState
     * @param {never} prevContext
     */
    UniversalComponent.prototype.componentDidUpdate = function (prevProps, prevState, prevContext) {
        this.plugins.forEach(function (plugin) {
            return plugin.componentDidUpdate && plugin.componentDidUpdate(prevProps, prevState, prevContext);
        });
    };
    /**
     * @stable [01.12.2018]
     * @returns {Element}
     */
    UniversalComponent.prototype.getSelf = function () {
        return this.selfRef.current || this.refs.self; // TODO any
    };
    /**
     * @stable [01.12.2018]
     */
    UniversalComponent.prototype.onNativeScroll = function () {
        if (util_1.isDef(this.scrollTask)) {
            this.scrollTask.start();
        }
    };
    /**
     * @stable [01.12.2018]
     */
    UniversalComponent.prototype.doScroll = function () {
        this.props.onScroll(this.domAccessor.getScrollInfo(this.getSelf()));
    };
    Object.defineProperty(UniversalComponent.prototype, "t", {
        /**
         * @stable [19.04.2018]
         * @returns {ApplicationTranslatorT}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.Translate);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "settings", {
        /**
         * @stable [19.04.2018]
         * @returns {IApplicationSettings}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.Settings);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "uiPlugins", {
        /**
         * @stable [23.04.2018]
         * @returns {Map<IUniversalComponentClassEntity, UniversalComponentPluginFactoryT>}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.UIPlugins);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "dc", {
        /**
         * @stable [13.05.2018]
         * @returns {IDateConverter}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.DateConverter);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "nc", {
        /**
         * @stable [13.05.2018]
         * @returns {INumberConverter}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.NumberConverter);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "uiFactory", {
        /**
         * @stable [18.05.2018]
         * @returns {IUIFactory}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.UIFactory);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalComponent.prototype, "domAccessor", {
        /**
         * @stable [01.12.2018]
         * @returns {IApplicationDomAccessor}
         */
        get: function () {
            return di_1.staticInjector(di_1.DI_TYPES.DomAccessor);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [01.12.2018]
     * @returns {React.RefObject<TElement extends Element>}
     */
    UniversalComponent.prototype.getSelfRef = function () {
        return this.selfRef;
    };
    /**
     * @stable [23.04.2018]
     * @param {IUniversalComponentPluginClassEntity} pluginClassEntity
     * @returns {IUniversalComponentPlugin}
     */
    UniversalComponent.prototype.registerPlugin = function (pluginClassEntity) {
        var plugin = Reflect.construct(pluginClassEntity, [this]);
        this.plugins.push(plugin);
        return plugin;
    };
    return UniversalComponent;
}(React.Component));
exports.UniversalComponent = UniversalComponent;
//# sourceMappingURL=universal.component.js.map