import * as React from 'react';
import { Store } from 'redux';
import { ILogger } from 'ts-smart-logger';
import { IKeyValue, AnyT } from '../../definitions.interface';
import { IContainerClassEntity, IUniversalContainer, IUniversalApplicationStoreEntity } from '../../entities-definitions.interface';
import { IConnectorConfiguration, IRoutesConfiguration } from '../../configurations-definitions.interface';
import { IUniversalContainerProps } from '../../props-definitions.interface';
import { IApplicationSettings } from '../../settings';
import { ApplicationTranslatorT } from '../../translation';
import { IDateConverter, INumberConverter } from '../../converter';
import { IAuthService } from '../../auth';
import { IUIFactory } from '../factory/factory.interface';
export declare class UniversalContainer<TProps extends IUniversalContainerProps = IUniversalContainerProps, TState = {}> extends React.Component<TProps, TState> implements IUniversalContainer<TProps, TState> {
    protected static logger: ILogger;
    private lifecycleTasks;
    /**
     * @stable - 12.04.2018
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [02.07.2018]
     * @param {TProps} props
     * @param {Readonly<TState>} nextState
     * @returns {boolean}
     */
    shouldComponentUpdate(props: TProps, nextState: Readonly<TState>): boolean;
    /**
     * @stable [07.06.2018]
     * @param {Readonly<TProps extends IUniversalContainerProps>} prevProps
     * @param {Readonly<TState>} prevState
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [18.11.2018]
     * @param {string} type
     * @param {TChanges} data
     */
    dispatch<TChanges = IKeyValue>(type: string, data?: TChanges): void;
    /**
     * Needed for the framework actions
     *
     * @stable [14.08.2018]
     * @param {string} type
     * @param {IKeyValue} data
     */
    dispatchFrameworkAction<TData = IKeyValue>(type: string, data?: TData): void;
    /**
     * @stable - 12.04.2018
     * @param {TPath0} path
     * @param {TState0} state
     */
    navigate<TPath0, TState0>(path: TPath0, state?: TState0): void;
    /**
     * @stable [18.11.2018]
     * @param {TChanges} changes
     */
    dispatchFormChanges<TChanges extends IKeyValue = IKeyValue>(changes: TChanges): void;
    /**
     * @stable [18.11.2018]
     * @param {string} fieldName
     * @param {AnyT} fieldValue
     */
    dispatchFormChange(fieldName: string, fieldValue?: AnyT): void;
    /**
     * @stable [18.11.2018]
     * @param {string} dictionary
     * @param {TData} data
     */
    dispatchLoadDictionary<TData = IKeyValue>(dictionary: string, data?: TData): void;
    /**
     * @stable - 12.04.2018
     */
    protected navigateToBack(): void;
    /**
     * Service method (DRY)
     * @stable - 12.04.2018
     * @param {string} operationId
     * @returns {boolean}
     */
    protected isTransportContainsExecutingOperation(operationId: string): boolean;
    /**
     * @stable - 12.04.2018
     * @param {string} type
     * @param {AnyT} data
     */
    protected dispatchCustomType(type: string, data?: AnyT): void;
    /**
     * @stable [26.08.2018]
     * @param {string} fieldName
     */
    protected dispatchFormClear(fieldName: string): void;
    /**
     * @stable - 15.04.2018
     * @returns {Store<{}>}
     */
    protected readonly appStore: Store<IUniversalApplicationStoreEntity>;
    /**
     * @stable - 15.04.2018
     * @returns {Map<IContainerClassEntity, IConnectorConfiguration>}
     */
    protected readonly dynamicRoutes: Map<IContainerClassEntity, IConnectorConfiguration>;
    /**
     * @stable - 15.04.2018
     * @returns {IRoutesConfiguration}
     */
    protected readonly routes: IRoutesConfiguration;
    /**
     * @stable - 15.04.2018
     * @returns {IApplicationSettings}
     */
    protected readonly settings: IApplicationSettings;
    /**
     * @stable [26.04.2018]
     * @returns {IAuthService}
     */
    protected readonly auth: IAuthService;
    /**
     * @stable - 15.04.2018
     * @returns {ApplicationTranslatorT}
     */
    protected readonly t: ApplicationTranslatorT;
    /**
     * @stable - 16.04.2018
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @stable - 16.04.2018
     * @returns {INumberConverter}
     */
    protected readonly nc: INumberConverter;
    /**
     * @stable [18.05.2018]
     * @returns {IUIFactory}
     */
    protected readonly uiFactory: IUIFactory;
    /**
     * @stable [07.06.2018]
     * @param {() => void} task
     */
    protected registerLifecycleTask(task: () => void): void;
    /**
     * @stable [27.08.2018]
     * @param {Error} e
     * @returns {React.ReactNode}
     */
    protected getErrorMessageElement(e: Error): React.ReactNode;
}
